==> mguatlas5k.db_2.2.5.tar.gz: mguatlas5k.db/man/mguatlas5k_dbconn.Rd <==
\name{mguatlas5k_dbconn}

\alias{mguatlas5k_dbconn}
\alias{mguatlas5k_dbfile}
\alias{mguatlas5k_dbschema}
\alias{mguatlas5k_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  mguatlas5k_dbconn()
  mguatlas5k_dbfile()
  mguatlas5k_dbschema(file="", show.indices=FALSE)
  mguatlas5k_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{mguatlas5k_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{mguatlas5k_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{mguatlas5k_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{mguatlas5k_dbschema} prints the schema definition of the
  package annotation DB.

  \code{mguatlas5k_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{mguatlas5k_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{mguatlas5k_dbfile}: a character string with the path to the
  package annotation DB.

  \code{mguatlas5k_dbschema}: none (invisible \code{NULL}).

  \code{mguatlas5k_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(mguatlas5k_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by mguatlas5k_dbconn() was created with:
  dbConnect(SQLite(), dbname=mguatlas5k_dbfile(), cache_size=64000, synchronous=0)

  mguatlas5k_dbschema()

  mguatlas5k_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> mguatlas5k.db_2.14.0.tar.gz: mguatlas5k.db/man/mguatlas5k_dbconn.Rd <==

\name{mguatlas5k_dbconn}

\alias{mguatlas5k_dbconn}
\alias{mguatlas5k_dbfile}
\alias{mguatlas5k_dbschema}
\alias{mguatlas5k_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  mguatlas5k_dbconn()
  mguatlas5k_dbfile()
  mguatlas5k_dbschema(file="", show.indices=FALSE)
  mguatlas5k_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{mguatlas5k_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{mguatlas5k_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{mguatlas5k_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{mguatlas5k_dbschema} prints the schema definition of the
  package annotation DB.

  \code{mguatlas5k_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{mguatlas5k_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{mguatlas5k_dbfile}: a character string with the path to the
  package annotation DB.

  \code{mguatlas5k_dbschema}: none (invisible \code{NULL}).

  \code{mguatlas5k_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(mguatlas5k_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by mguatlas5k_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=mguatlas5k_dbfile(), cache_size=64000,
  synchronous=0)

  mguatlas5k_dbschema()

  mguatlas5k_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
